@@ -25,6 +25,7 @@
 #include "message_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
+#include "helper_p.h"
 
 namespace KIMAP
 {
@@ -115,7 +116,7 @@ void AppendJob::doStart()
 
     if (!d->flags.isEmpty()) {
         parameters += " (";
-        foreach (const QByteArray &flag, d->flags) {
+        for (const QByteArray &flag : qAsConst(d->flags)) {
             parameters += flag + ' ';
         }
         parameters.chop(1);
@@ -135,12 +136,12 @@ void AppendJob::doStart()
 void AppendJob::handleResponse(const Message &response)
 {
     Q_D(AppendJob);
-
+    const QList<Message::Part>::ConstIterator end(response.responseCode.end());
     for (QList<Message::Part>::ConstIterator it = response.responseCode.begin();
-            it != response.responseCode.end(); ++it) {
+            it != end; ++it) {
         if (it->toString() == "APPENDUID") {
             it = it + 2;
-            if (it != response.responseCode.end()) {
+            if (it != end) {
                 d->uid = it->toString().toLongLong();
             }
             break;
